window.Gleam.initSearch([{"doc":"string_width","title":"string_width","content":"# string_width\n\n[![Package Version](https://img.shields.io/hexpm/v/string_width)](https://hex.pm/packages/string_width)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/string_width/)\n\n```sh\ngleam add string_width@2\n```\n```gleam\nimport string_width\n\npub fn main() {\n  string_width.dimensions(&quot;hello,\\n안녕하세요&quot;, [])\n  // --&gt; #(2, 10)\n\n  string_width.line(&quot;👩‍👩‍👦‍👦&quot;, [string_width.HandleGraphemeClusters])\n  // --&gt; 2\n}\n```\n\nA small package estimating the required number of cells when printing a string on the terminal. It supports all Gleam targets and passes the tests of the NPM [string-width](https://www.npmjs.com/package/string-width) package.\n\n### Limitations\n\n- Many terminals don&#39;t support grapheme clusters properly, so by default, the\n  values returned by this library try to match the behaviour of libc instead\n  of modern text rendering pipelines.\n\n- The width of many characters is context-dependent and may vary based on the\n  current locale, selected font, operating system, or surrounding context;\n  The numbers reported by the functions in this library may not be fully accurate.\n\n  If you encounter a mismatch that is consistent across multiple environments,\n  feel free to open an issue or ping me on Discord!\n\n- The behaviour when encountering stray variant selectors does not match other similar libraries.\n\n\n### Sources\n\nThe table lookup technique used by this library is heavily based on the musl libc `wcwidth` implementation. I built updated tables using the Unicode 16.0 data, and added support for ambiguous characters. It also uses the regex of the ansi-regex npm package, and the test cases of the string-width npm package.\n\n\n- **UAX #11 East Asian Width:** [https://www.unicode.org/reports/tr11/](https://www.unicode.org/reports/tr11/)\n- **Grapheme Clusters in Terminals:** [https://mitchellh.com/writing/grapheme-clusters-in-terminals](https://mitchellh.com/writing/grapheme-clusters-in-terminals)\n- **get-east-asian-width:** [https://github.com/sindresorhus/get-east-asian-width](https://github.com/sindresorhus/get-east-asian-width)\n- **string-width:** [https://github.com/sindresorhus/string-width](https://github.com/sindresorhus/string-width)\n- **ansi-regex:** [https://github.com/chalk/ansi-regex](https://github.com/chalk/ansi-regex)\n- **musl-libc wcwidth:** [https://git.musl-libc.org/cgit/musl/tree/src/ctype/wcwidth.c](https://git.musl-libc.org/cgit/musl/tree/src/ctype/wcwidth.c)\n- **glibc wcwidth:** [https://sourceware.org/git/?p=glibc.git;a=blob;f=wcsmbs/wcwidth.h;hb=HEAD](https://sourceware.org/git/?p=glibc.git;a=blob;f=wcsmbs/wcwidth.h;hb=HEAD)\n","url":"index.html"},{"doc":"string_width","title":"Option","content":"pub type Option {\n  HandleGraphemeClusters\n  CountAnsiEscapeCodes\n  AmbiguousAsWide\n}\n\nHandleGraphemeClusters\n Many terminal emulators do not handle grapheme clusters well and will\n instead show their decomposition. To make sure a given string always fits\n even on those terminals, the functions in this package will copy this\n behaviour as well.\n \n If you pass this option, the returned numbers will more accurately represent\n the width of a string on a website or in an editor, and will match the\n behaviour of the Javascript [string-width](https://www.npmjs.com/package/string-width) package.\n \n See also [Grapheme Clusters and Terminal Emulators](https://mitchellh.com/writing/grapheme-clusters-in-terminals)\n for a better explanation on how terminals behave.\n\nCountAnsiEscapeCodes\n Do not ignore ansi escape sequences.\n\nAmbiguousAsWide\n Some characters are marked by Unicode as &quot;ambiguous&quot;, meaning they may\n occupy 1 or 2 cells, depending on the context, current language, selected\n font, surrounding text, and more.\n\n Unicode recommends treating these characters as narrow by default,\n but you can change this behaviour using this option.\n\nSynonyms:\nstring_width.Option\nstring_width Option","url":"string_width.html#Option"},{"doc":"string_width","title":"codepoint","content":"pub fn codepoint(chr: UtfCodepoint, options: List(Option)) -&gt; Int\n Estimate the required width for a single unicode code point.\n \n **Note:** that the exact width is context-dependent, so this value may not\n exactly match what you might expect!\n \n If you encounter a mismatch that is consistent across multiple terminal\n emulators, please open an issue or ping me on Discord!\nSynonyms:\nstring_width.codepoint\nstring_width codepoint","url":"string_width.html#codepoint"},{"doc":"string_width","title":"dimensions","content":"pub fn dimensions(\n  str: String,\n  options: List(Option),\n) -&gt; #(Int, Int)\n The required number of rows and columns to display the given text.\n \n The number of rows is equal to the number of lines, while the number of\n columns represents the maximum line width.\n \n ### Examples\n \n \n dimensions(&quot;안녕하세요&quot;, [])\n // --&gt; #(1, 10)\n \n dimensions(&quot;hello,\\n안녕하세요&quot;, [])\n // --&gt; #(2, 10)\n \nSynonyms:\nstring_width.dimensions\nstring_width dimensions","url":"string_width.html#dimensions"},{"doc":"string_width","title":"grapheme_cluster","content":"pub fn grapheme_cluster(\n  grapheme: String,\n  options: List(Option),\n) -&gt; Int\n Estimate the required width for a single grapheme cluster.\n \n **Note:** that the exact width is context-dependent, so this value may not\n exactly match what you might expect!\n \n If you encounter a mismatch that is consistent across multiple terminal\n emulators, please open an issue or ping me on Discord!\nSynonyms:\nstring_width.grapheme_cluster\nstring_width grapheme_cluster","url":"string_width.html#grapheme_cluster"},{"doc":"string_width","title":"int_codepoint","content":"pub fn int_codepoint(cp: Int, options: List(Option)) -&gt; Int\n \nSynonyms:\nstring_width.int_codepoint\nstring_width int_codepoint","url":"string_width.html#int_codepoint"},{"doc":"string_width","title":"line","content":"pub fn line(str: String, options: List(Option)) -&gt; Int\n Get the width of a line, when printed using a monospace font.\n \n Line breaks are ignored. If the given string contains newlines,\n the result is undefined.\n \n ### Examples\n \n \n line(&quot;äöüè&quot;, [])\n // --&gt; 4\n \n line(&quot;안녕하세요&quot;, [])\n // --&gt; 10\n\n line(&quot;👩‍👩‍👦‍👦&quot;, [])\n // --&gt; 8\n \n line(&quot;👩‍👩‍👦‍👦&quot;, [HandleGraphemeClusters])\n // --&gt; 2\n \n line(&quot;\\u{1B}[31mhello\\u{1B}[39m&quot;, [])\n // --&gt; 5\n \nSynonyms:\nstring_width.line\nstring_width line","url":"string_width.html#line"},{"doc":"string_width","title":"string_width","content":"","url":"string_width.html"}]);